Module intent

Module intent 

Extraction intent — controls how much data a query returns to conserve tokens.

Enums

ExtractionIntent
The level of detail a query should return.
ScopedResult
The result of a scoped query, carrying only the requested level of detail.

Traits

Scopeable
Trait for types that can be scoped to different extraction intents.

Functions

apply_intent
Apply an extraction intent to a collection of scopeable items.