pub fn apply_intent<T: Scopeable + Clone + Serialize>(
items: &[T],
intent: ExtractionIntent,
) -> ScopedResult<T>Expand description
Apply an extraction intent to a collection of scopeable items.
pub fn apply_intent<T: Scopeable + Clone + Serialize>(
items: &[T],
intent: ExtractionIntent,
) -> ScopedResult<T>Apply an extraction intent to a collection of scopeable items.