Extraction intent — controls how much data a query returns to conserve tokens.
Enums
- Extraction
Intent - The level of detail a query should return.
- Scoped
Result - The result of a scoped query, carrying only the requested level of detail.
Traits
- Scopeable
- Trait for types that can be scoped to different extraction intents.
Functions
- apply_
intent - Apply an extraction intent to a collection of scopeable items.